# Our Asynchronously Interchangeable Objects Server

this open source Python django server project allows you to share, backup and synchronize any data between
multiple hosts, users and their devices.


## credits

the [freely available prooject code](https://gitlab.com/ae-group/oaios) is based on portions of the
[__ae__ namespace (Application Environment)](https://ae.readthedocs.io "ae on rtd"),
maintained by the [GitLab User Group ae-group](https://gitlab.com/ae-group).

additional credits to:

* [__Erokia__](https://freesound.org/people/Erokia/) and 
  [__plasterbrain__](https://freesound.org/people/plasterbrain/) at
  [freesound.org](https://freesound.org) for the sounds.
* [__iconmonstr__](https://iconmonstr.com/interface/) and
  [__Google__](https://fonts.google.com/icons?icon.set=Material+Symbols) for the icon images.
